@@ -240,6 +240,7 @@ class Model:
     def Models(name:str):
         return {
             "Students_problem":Model(Composition= Model.Composition_conjunction_matric,Rule_withdrawal =Model.Withdrawal_rule_absent,Rule_distribution_truth=Model.Truth_distribution_students_problem),
+            "Students_problem2":Model(Composition= Model.Composition_conjunction_matric,Rule_withdrawal =Model.Withdrawal_rule_modus_ponens,Rule_distribution_truth=Model.Truth_distribution_students_problem),
             "Mamdani_matrix" :Model(),
             "Mamdani_nomatrix": Model(Composition= Model.Composition_conjunction_nematric,Rule_accumulation=Model.Accumulation_disjunction_nematric,Method_defuzzification=Model.defuzzification_method_centration_tightness_points),
             "Cukamoto":Model(Composition=Model.Composition_conjunction_nematric,Addition= Model.Addition_Cukamoto, Rule_accumulation = lambda  ux: None,Method_defuzzification = Model.defuzzification_method_centration_tightness_modify),
@@ -278,21 +279,27 @@ class Fuzzy_output:
     def Predict(self,x:List[float]):
         
         List_var1 = self.Linguistic_variables.copy()
-        for i in self.Rules.Consequent: #Формирование списка входных переменных
-            if i in List_var1:
-                List_var1.remove(i)
-            else:
-                i.Defuzzified_Input_parameter = None
-                i.Accumulated_function = None
+        for i in self.Rules: #Формирование списка входных переменных
+            for j in i.Consequent.List_statements:
+                if j.Linguistic_variable in List_var1:
+                    List_var1.remove(j.Linguistic_variable)
+                else:
+                    j.Linguistic_variable.Defuzzified_Input_parameter = None
+                    j.Linguistic_variable.Accumulated_function = None
             
         for i in range(0,len(List_var1)): # Задание значений входных переменных
-           List_var1[i].Input_parametr_value = x[i]
-        
-        self.Withdrawal(Reading_file = False) # логический вывод и формирование новых дефаззифицированных значений 
-        
-        return [y.Defuzzified_Input_parameter_value for y in 
-                self.Linguistic_variables if hasattr(y,"Accumulated_function")]
+            for j in [x for x in self.Linguistic_variables if x == List_var1[i]]:
+                j.Input_parameter_value = x[i]
 
+        for k in self.Fuzzy_variables:
+            k.A = next(val for (key,val) in self.functions.items() if key.Name == k.Name).copy()
+        
+        for k in self.Rules:
+            k.Not_using = True
+        
+        return self.Withdrawal(Model=Model.Models("Students_problem"),Reading_files = False) # логический вывод и формирование новых дефаззифицированных значений 
+        
+         
     def Withdrawal (self, Model = Model(),Reading_files = True):
         def Formation_base_references():
             def Read_Table(function, Name_file):
@@ -389,7 +396,7 @@ class Fuzzy_output:
                             if Statement.Linguistic_variable.Input_parameter_value is not None:
                                 Addition(Statement,Statement.Term.A[Statement.Linguistic_variable.Input_parameter_value])
                     except Exception as e:
-                        print(e)
+                        pass#print(e)
                     finally:
                         Rule.Not_using = False
                                     
@@ -405,6 +412,7 @@ class Fuzzy_output:
 
         if Reading_files:
             Formation_base_references()
+            self.functions = dict((NP,NP.A) for NP in self.Fuzzy_variables.copy())
        
         while True:
             Использованность_правил = [not x.Not_using for x in self.Rules]
@@ -418,12 +426,15 @@ class Fuzzy_output:
             if all([not x.Not_using for x in self.Rules]) or all([a==p for a,p in zip(Использованность_правил,[not x.Not_using for x in self.Rules])]):
                break
         
+        вывод = ""
         for ЛП in self.Linguistic_variables:
             try:
                 if hasattr(ЛП,"Accumulated_function"): 
-                    print(ЛП.Defuzzified_Input_parameter_value)
+                    вывод += str(round(ЛП.Defuzzified_Input_parameter_value,2))
             except:
                 print("Error")  
+        
+        return вывод
    
     def __str__(self):
         return """
@@ -434,4 +445,16 @@ class Fuzzy_output:
     """.format(
         Fuzzy_variables = "\n".join([str(Переменная) for Переменная in self.Fuzzy_variables]), 
         Linguistic_variables = "\n".join([str(Переменная) for Переменная in self.Linguistic_variables]),
-        Rules = "\n".join([str(Rule) for Rule in self.Rules])) 
\ No newline at end of file
+        Rules = "\n".join([str(Rule) for Rule in self.Rules])) 
+    
+дз = Fuzzy_output()
+print(дз.Withdrawal(Model.Models("Students_problem")))
+
+st2 = ""
+for i in range(0,11,1):
+    for j in range(0,11,1):
+        for k in range(0,11,1):
+            st = дз.Predict([float(i),float(j),float(k)]) 
+            if st != st2 and st!="0":
+                print(f"{i}:{j}:{k} - {st}")
+                st2 = st
\ No newline at end of file
